==> dadrill-0.5.tar.gz: add-paper-form.php <==
<?
/******************************************************************************
  daDrill, an offline BibTeX library browser
  Copyright (C) 2005  Sylvain Hall
  
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
  MA  02110-1301, USA.
******************************************************************************/
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" 
  "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html>
<!--
  daDrill template page
  Author:         Sylvain Halle <sylvain@leduotang.com>
  Last modif.:    2005-09-13
-->
<head>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1"/>
<link rel="stylesheet" type="text/css" href="page.css"/>
<link rel="shortcut icon" href="images/dadrill.ico"/>
<meta name="lang" content="en"/>
<meta name="robots" content="noindex,nofollow"/>
<meta name="author" content="Sylvain Hall&eacute;"/>
<meta name="description" content="Page from daDrill, the offline library browser."/>
<title>
daDrill - Add paper
</title>
</head>
<body>

<table border="0" cellpadding="0" cellspacing="0" width="100%" style="height:100%">
<tr><td style="height:48px;">
  <table border="0" cellpadding="0" cellspacing="0" width="100%" style="height:48px;">
  <tr>
  <td width="82">
  <img src="images/page-1-w.png" alt=""/>
  </td>
  <td style="background-image:url('images/page-1-c.png');">&nbsp;</td>
  <td width="128">
  <img src="images/page-1-e.png" alt=""/>
  </td>
  </tr>
  </table>
</td></tr>
<tr><td style="height:40px;">
  <table border="0" cellpadding="0" cellspacing="0" width="100%" style="height:40px;">
  <tr>
  <td width="101">
  <img src="images/page-2-w.png" alt=""/>
  </td>
  <td class="menubar" valign="middle" style="background-image:url('images/page-2-c.png');">
    <!-- Begin menu bar -->
    <table border="0" cellpadding="0" cellspacing="0">
    <tr>
    <td>
    <a href="./" class="menubar">Home</a>
    <img src="images/nothing.png" width="15" alt=""/>
    </td>
    <td>
    <a href="browse.php"><img border="0" src="images/button-browse.png" alt="Browse"/></a>
    </td>
    <td>
    <a href="browse.php" class="menubar">Browse</a>
    <img src="images/nothing.png" width="15" alt=""/>
    </td>
    <td>
    <a href="query.php"><img border="0" src="images/button-query.png" alt="Query"/></a>
    </td>
    <td>
    <a href="query.php" class="menubar">Query</a>
    <img src="images/nothing.png" width="15" alt=""/>
    </td>
    <td>
    <a href="add.php"><img border="0" src="images/button-add.png" alt="Add"/></a>
    </td>
    <td>
    <a href="add.php" class="menubar">Add</a>
    <img src="images/nothing.png" width="15" alt=""/>
    </td>
    <td>
    <a href="about.php"><img border="0" src="images/button-about.png" alt="About"/></a>
    </td>
    <td>
    <a href="about.php" class="menubar">About</a>
    <img src="images/nothing.png" width="15" alt=""/>
    </td>
    </tr>
    </table>
    <!-- End menu bar -->
  </td>
  <td width="128">
  <img src="images/page-2-e.png" alt=""/>
  </td>
  </tr>
  </table>
</td></tr>
<tr><td valign="top">
  <table border="0" cellpadding="0" cellspacing="0" width="100%">
  <tr>
  <td width="100">&nbsp;</td>
  <td valign="top">
  <!-- Begin page content -->
  <h1>Add paper</h1>
  <form name="getbibtex" method="post" action="paper-add.php">
  <table border="0" cellspacing="5">
  <tr>
    <td><b>Field name</b></td>
    <td><b>Value</b></td>
  </tr>
  <tr>
    <td valign="top" align="right">BibTeX type</td>
    <td><select name="typeBibtex">
      <option name="article">article</option>
      <option name="book">book</option>
      <option name="booklet">booklet</option>
      <option name="conference">conference</option>
      <option name="inbook">inbook</option>
      <option name="incollection">incollection</option>
      <option name="inproceedings" selected>inproceedings</option>
      <option name="manual">manual</option>
      <option name="mastersthesis">mastersthesis</option>
      <option name="misc">misc</option>
      <option name="phdthesis">phdthesis</option>
      <option name="proceedings">proceedings</option>
      <option name="phdthesis">phdthesis</option>
      <option name="techreport">techreport</option>
      <option name="unpublished">unpublished</option>
      <option name="collection">collection</option>
      <option name="patent">patent</option>
      </select>
    </td>
  </tr>
  <tr>
    <td valign="top" align="right">BibTeX identifier</td>
    <td><input type="text" name="identifierBibtex" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Abstract</td>
    <td><textarea name="bibtexAbstract" rows="5" cols="80"></textarea></td>
  </tr>
  <tr>
    <td valign="top" align="right">Address</td>
    <td><input type="text" name="bibtexAddress" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Affiliation</td>
    <td><input type="text" name="bibtexAffiliation" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Annote</td>
    <td><input type="text" name="bibtexAnnote" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Author(s)</td>
    <td><input type="text" name="bibtexAuthor" value="" size="80" /><br/>
    <input type="checkbox" name="autoadd" value="1"/> Auto-add/merge authors
    </td>
  </tr>
  <tr>
    <td valign="top" align="right">Bibsource</td>
    <td><input type="text" name="bibtexBibsource" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Book title</td>
    <td><input type="text" name="bibtexBooktitle" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Chapter</td>
    <td><input type="text" name="bibtexChapter" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Comments*</td>
    <td><textarea name="comments" rows="10" cols="80"></textarea></td>
  </tr>
  <tr>
    <td valign="top" align="right">Contents</td>
    <td><input type="text" name="bibtexContents" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Copyright</td>
    <td><input type="text" name="bibtexCopyright" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Cross-reference</td>
    <td><input type="text" name="bibtexCrossref" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Edition</td>
    <td><input type="text" name="bibtexEdition" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Editor(s)</td>
    <td><input type="text" name="bibtexEditor" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">EE</td>
    <td><input type="text" name="bibtexEe" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">How published</td>
    <td><input type="text" name="bibtexHowpublished" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Institution</td>
    <td><input type="text" name="bibtexInstitution" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">ISBN</td>
    <td><input type="text" name="bibtexIsbn" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">ISSN</td>
    <td><input type="text" name="bibtexIssn" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Journal</td>
    <td><input type="text" name="bibtexJournal" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Key</td>
    <td><input type="text" name="bibtexKey" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Keywords</td>
    <td><input type="text" name="bibtexKeywords" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Language</td>
    <td><input type="text" name="bibtexLanguage" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">LCCN</td>
    <td><input type="text" name="bibtexLccn" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Local PDF file*</td>
    <td><input type="text" name="localUrlpdf" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Local PS file*</td>
    <td><input type="text" name="localUrlps" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Location</td>
    <td><input type="text" name="bibtexLocation" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Month</td>
    <td><input type="text" name="bibtexMonth" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Note</td>
    <td><input type="text" name="bibtexNote" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Number</td>
    <td><input type="text" name="bibtexNumber" value="" size="80"/></td>
  </tr>
  <tr>
    <td valign="top" align="right">Organization</td>
    <td><input type="text" name="bibtexOrganization" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Pages</td>
    <td><input type="text" name="bibtexPages" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Price</td>
    <td><input type="text" name="bibtexPrice" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Publisher</td>
    <td><input type="text" name="bibtexPublisher" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">School</td>
    <td><input type="text" name="bibtexSchool" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Series</td>
    <td><input type="text" name="bibtexSeries" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Size</td>
    <td><input type="text" name="bibtexSize" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Title</td>
    <td><input type="text" name="bibtexTitle" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Type</td>
    <td><input type="text" name="bibtexType" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">URL</td>
    <td><input type="text" name="bibtexUrl" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Year</td>
    <td><input type="text" name="bibtexYear" value="" size="80" /></td>
  </tr>
  </table>
  
  <p><input type="submit" value="Submit"> <input type="reset" value="Reset"/></p>
  </form>
  <p>* Indicates unofficial BibTeX fields</p>
  <!-- End page content -->
  </td>
  <td width="10">&nbsp;</td>
  </tr>
  </table>
</td></tr>
<tr><td style="height:40px;">
  <table border="0" cellpadding="0" cellspacing="0" width="100%" style="height:40px;">
  <tr>
  <td width="86">
  <img src="images/page-b-w.png" alt=""/>
  </td>
  <td valign="middle" class="footer" style="background-image:url('images/page-b-c.png');">
  <!-- Begin footer -->
  &copy; 2005 Sylvain Hall&eacute;.  This software is released under the GNU
  GPL; see <a style="color:#cc0" href="COPYING">COPYING</a> for license
  information.  This page (and script) was last modified on
  <!-- date-modif -->2005-09-13.
  <!-- End footer -->
  </td>
  <td width="25">
  <img src="images/page-b-e.png" alt=""/>
  </td>
  </tr>
  </table>
</td></tr>
</table>

</body>
</html>
<?
// Closes connection
db_close($db);
?>

==> dadrill-0.6.tar.gz: add-paper-form.php <==
<?
/******************************************************************************
  daDrill, an offline BibTeX library browser
  Copyright (C) 2005  Sylvain Hall
  
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
  MA  02110-1301, USA.
******************************************************************************/
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" 
  "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html>
<!--
  daDrill template page
  Author:         Sylvain Halle <sylvain@leduotang.com>
  Last modif.:    2005-09-13
-->
<head>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1"/>
<link rel="stylesheet" type="text/css" href="page.css"/>
<link rel="shortcut icon" href="images/dadrill.ico"/>
<meta name="lang" content="en"/>
<meta name="robots" content="noindex,nofollow"/>
<meta name="author" content="Sylvain Hall&eacute;"/>
<meta name="description" content="Page from daDrill, the offline library browser."/>
<title>
daDrill - Add paper
</title>
</head>
<body>

<table border="0" cellpadding="0" cellspacing="0" width="100%" style="height:100%">
<tr><td style="height:48px;">
  <table border="0" cellpadding="0" cellspacing="0" width="100%" style="height:48px;">
  <tr>
  <td width="82">
  <img src="images/page-1-w.png" alt=""/>
  </td>
  <td style="background-image:url('images/page-1-c.png');">&nbsp;</td>
  <td width="128">
  <img src="images/page-1-e.png" alt=""/>
  </td>
  </tr>
  </table>
</td></tr>
<tr><td style="height:40px;">
  <table border="0" cellpadding="0" cellspacing="0" width="100%" style="height:40px;">
  <tr>
  <td width="101">
  <img src="images/page-2-w.png" alt=""/>
  </td>
  <td class="menubar" valign="middle" style="background-image:url('images/page-2-c.png');">
    <!-- Begin menu bar -->
    <table border="0" cellpadding="0" cellspacing="0">
    <tr>
    <td>
    <a href="./" class="menubar">Home</a>
    <img src="images/nothing.png" width="15" alt=""/>
    </td>
    <td>
    <a href="browse.php"><img border="0" src="images/button-browse.png" alt="Browse"/></a>
    </td>
    <td>
    <a href="browse.php" class="menubar">Browse</a>
    <img src="images/nothing.png" width="15" alt=""/>
    </td>
    <td>
    <a href="query.php"><img border="0" src="images/button-query.png" alt="Query"/></a>
    </td>
    <td>
    <a href="query.php" class="menubar">Query</a>
    <img src="images/nothing.png" width="15" alt=""/>
    </td>
    <td>
    <a href="add.php"><img border="0" src="images/button-add.png" alt="Add"/></a>
    </td>
    <td>
    <a href="add.php" class="menubar">Add</a>
    <img src="images/nothing.png" width="15" alt=""/>
    </td>
    <td>
    <a href="about.php"><img border="0" src="images/button-about.png" alt="About"/></a>
    </td>
    <td>
    <a href="about.php" class="menubar">About</a>
    <img src="images/nothing.png" width="15" alt=""/>
    </td>
    </tr>
    </table>
    <!-- End menu bar -->
  </td>
  <td width="128">
  <img src="images/page-2-e.png" alt=""/>
  </td>
  </tr>
  </table>
</td></tr>
<tr><td valign="top">
  <table border="0" cellpadding="0" cellspacing="0" width="100%">
  <tr>
  <td width="100">&nbsp;</td>
  <td valign="top">
  <!-- Begin page content -->
  <h1>Add paper</h1>
  <form name="getbibtex" method="post" action="paper-add.php">
  <table border="0" cellspacing="5">
  <tr>
    <td><b>Field name</b></td>
    <td><b>Value</b></td>
  </tr>
  <tr>
    <td valign="top" align="right">BibTeX type</td>
    <td><select name="typeBibtex">
      <option value="article">article</option>
      <option value="book">book</option>
      <option value="booklet">booklet</option>
      <option value="conference">conference</option>
      <option value="inbook">inbook</option>
      <option value="incollection">incollection</option>
      <option value="inproceedings" selected>inproceedings</option>
      <option value="manual">manual</option>
      <option value="mastersthesis">mastersthesis</option>
      <option value="misc">misc</option>
      <option value="phdthesis">phdthesis</option>
      <option value="proceedings">proceedings</option>
      <option value="phdthesis">phdthesis</option>
      <option value="techreport">techreport</option>
      <option value="unpublished">unpublished</option>
      <option value="collection">collection</option>
      <option value="patent">patent</option>
      </select>
    </td>
  </tr>
  <tr>
    <td valign="top" align="right">BibTeX identifier</td>
    <td><input type="text" name="identifierBibtex" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Abstract</td>
    <td><textarea name="bibtexAbstract" rows="5" cols="80"></textarea></td>
  </tr>
  <tr>
    <td valign="top" align="right">Address</td>
    <td><input type="text" name="bibtexAddress" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Affiliation</td>
    <td><input type="text" name="bibtexAffiliation" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Annote</td>
    <td><input type="text" name="bibtexAnnote" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Author(s)</td>
    <td><input type="text" name="bibtexAuthor" value="" size="80" /><br/>
    <input type="checkbox" name="autoadd" value="1"/> Auto-add/merge authors
    </td>
  </tr>
  <tr>
    <td valign="top" align="right">Bibsource</td>
    <td><input type="text" name="bibtexBibsource" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Book title</td>
    <td><input type="text" name="bibtexBooktitle" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Chapter</td>
    <td><input type="text" name="bibtexChapter" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Comments*</td>
    <td><textarea name="comments" rows="10" cols="80"></textarea></td>
  </tr>
  <tr>
    <td valign="top" align="right">Contents</td>
    <td><input type="text" name="bibtexContents" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Copyright</td>
    <td><input type="text" name="bibtexCopyright" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Cross-reference</td>
    <td><input type="text" name="bibtexCrossref" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Edition</td>
    <td><input type="text" name="bibtexEdition" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Editor(s)</td>
    <td><input type="text" name="bibtexEditor" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">EE</td>
    <td><input type="text" name="bibtexEe" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">How published</td>
    <td><input type="text" name="bibtexHowpublished" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Institution</td>
    <td><input type="text" name="bibtexInstitution" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">ISBN</td>
    <td><input type="text" name="bibtexIsbn" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">ISSN</td>
    <td><input type="text" name="bibtexIssn" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Journal</td>
    <td><input type="text" name="bibtexJournal" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Key</td>
    <td><input type="text" name="bibtexKey" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Keywords</td>
    <td><input type="text" name="bibtexKeywords" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Language</td>
    <td><input type="text" name="bibtexLanguage" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">LCCN</td>
    <td><input type="text" name="bibtexLccn" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Local PDF file*</td>
    <td><input type="text" name="localUrlpdf" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Local PS file*</td>
    <td><input type="text" name="localUrlps" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Location</td>
    <td><input type="text" name="bibtexLocation" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Month</td>
    <td><input type="text" name="bibtexMonth" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Note</td>
    <td><input type="text" name="bibtexNote" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Number</td>
    <td><input type="text" name="bibtexNumber" value="" size="80"/></td>
  </tr>
  <tr>
    <td valign="top" align="right">Organization</td>
    <td><input type="text" name="bibtexOrganization" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Pages</td>
    <td><input type="text" name="bibtexPages" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Price</td>
    <td><input type="text" name="bibtexPrice" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Publisher</td>
    <td><input type="text" name="bibtexPublisher" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">School</td>
    <td><input type="text" name="bibtexSchool" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Series</td>
    <td><input type="text" name="bibtexSeries" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Size</td>
    <td><input type="text" name="bibtexSize" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Title</td>
    <td><input type="text" name="bibtexTitle" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Type</td>
    <td><input type="text" name="bibtexType" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">URL</td>
    <td><input type="text" name="bibtexUrl" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Volume</td>
    <td><input type="text" name="bibtexVolume" value="" size="80" /></td>
  </tr>
  <tr>
    <td valign="top" align="right">Year</td>
    <td><input type="text" name="bibtexYear" value="" size="80" /></td>
  </tr>
  </table>
  
  <p><input type="submit" value="Submit"/> <input type="reset" value="Reset"/></p>
  </form>
  <p>* Indicates unofficial BibTeX fields</p>
  <!-- End page content -->
  </td>
  <td width="10">&nbsp;</td>
  </tr>
  </table>
</td></tr>
<tr><td style="height:40px;">
  <table border="0" cellpadding="0" cellspacing="0" width="100%" style="height:40px;">
  <tr>
  <td width="86">
  <img src="images/page-b-w.png" alt=""/>
  </td>
  <td valign="middle" class="footer" style="background-image:url('images/page-b-c.png');">
  <!-- Begin footer -->
  &copy; 2005 Sylvain Hall&eacute;.  This software is released under the GNU
  GPL; see <a style="color:#cc0" href="COPYING">COPYING</a> for license
  information.  This page (and script) was last modified on
  <!-- date-modif -->2006-03-21.
  <!-- End footer -->
  </td>
  <td width="25">
  <img src="images/page-b-e.png" alt=""/>
  </td>
  </tr>
  </table>
</td></tr>
</table>

</body>
</html>
